==> check-mk_1.2.6p12.orig.tar.gz: src/IntColumnFilter.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef IntColumnFilter_h
#define IntColumnFilter_h

#include "config.h"

#include <string>
using namespace std;

#include "Filter.h"
class IntColumn;

class IntColumnFilter : public Filter
{
    IntColumn *_column;
    int _opid;
    bool _negate;
    string _ref_string;

public:
    IntColumnFilter(IntColumn *column, int opid, char *value);
    virtual int32_t convertRefValue(); // see TimeColumnFilter
    bool accepts(void *data);
    void findIntLimits(const char *columnname, int *lower, int *upper);
    bool optimizeBitmask(const char *columnname, uint32_t *mask);
};


#endif // IntColumnFilter_h

==> check-mk_1.2.8p16.orig.tar.gz: src/IntColumnFilter.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef IntColumnFilter_h
#define IntColumnFilter_h

#include "config.h"  // IWYU pragma: keep
#include <stdint.h>
#include <string>
#include "Filter.h"
class IntColumn;

class IntColumnFilter : public Filter {
    IntColumn *_column;
    int _opid;
    bool _negate;
    std::string _ref_string;

public:
    IntColumnFilter(IntColumn *column, int opid, char *value);
    virtual int32_t convertRefValue();  // see TimeColumnFilter
    bool accepts(void *data);
    void findIntLimits(const char *columnname, int *lower, int *upper);
    bool optimizeBitmask(const char *columnname, uint32_t *mask);
};

#endif  // IntColumnFilter_h
